@@ -25,4 +25,5 @@
 #' }
 #'  
 #' @source \url{http://www.webofknowledge.com}
-"biblio_df"
\ No newline at end of file
+#' @name biblio_df
+NULL
